@@ -10,10 +10,10 @@
   --with-libiconv-prefix=$PREFIX/iconv \
   --enable-static \
   --with-libintl-prefix=$PREFIX/gettext \
-  PTW32_LIBS="-lpthread -lpcreposix -lpcre -lregex" \
+  PTW32_LIBS="-lpthread -lpcreposix -lpcre" \
   FLTK_CONFIG=$PREFIX/bin/i686-w64-mingw32.static-fltk-config \
 
-make
+make -j 8
 
 $PREFIX/bin/i686-w64-mingw32.static-strip src/fldigi.exe
 $PREFIX/bin/i686-w64-mingw32.static-strip src/flarq.exe
