@@ -43,6 +43,7 @@
 
 #include "psk_browser.h"
 #include "view_rtty.h"
+#include "spectrum_viewer.h"
 
 extern pskBrowser *mainViewer;
 
@@ -82,10 +83,14 @@ void initViewer()
 		if (active_modem->get_mode() == MODE_RTTY) {
 			mvsquelch->range(-12.0, 6.0);
 			mvsquelch->value(progStatus.VIEWER_rttysquelch);
+		} else if (active_modem->get_mode() == MODE_CW) {
+			mvsquelch->range(0.0, 40.0);
+			mvsquelch->value(progStatus.VIEWER_cwsquelch);
 		} else {
 			mvsquelch->range(-3.0, 6.0);
 			mvsquelch->value(progStatus.VIEWER_psksquelch);
 		}
+		mvsquelch->redraw();
 	}
 	if (brwsViewer) {
 		brwsViewer->usb = usb;
@@ -103,10 +108,14 @@ void initViewer()
 		if (active_modem->get_mode() == MODE_RTTY) {
 			sldrViewerSquelch->range(-12.0, 6.0);
 			sldrViewerSquelch->value(progStatus.VIEWER_rttysquelch);
+		} else if (active_modem->get_mode() == MODE_CW) {
+			sldrViewerSquelch->range(0.0, 40.0);
+			sldrViewerSquelch->value(progStatus.VIEWER_cwsquelch);
 		} else {
 			sldrViewerSquelch->range(-3.0, 6.0);
 			sldrViewerSquelch->value(progStatus.VIEWER_psksquelch);
 		}
+		sldrViewerSquelch->redraw();
 	}
 	active_modem->clear_viewer();
 }
@@ -119,7 +128,7 @@ void viewaddchr(int ch, int freq, char c, int md)
 			mainViewer->usb = wf->USB();
 			mainViewer->redraw();
 		}
-		mainViewer->addchr(ch, freq, c, md);
+		mainViewer->addchr(ch, freq, c, md, true);
 	}
 	if (dlgViewer) {
 		if (brwsViewer->rfc != wf->rfcarrier() || brwsViewer->usb != wf->USB()) {
@@ -211,6 +220,7 @@ static void cb_brwsViewer(Fl_Hold_Browser*, void*) {
 				ReceiveText->addstr(brwsViewer->line(sel).c_str(), FTextBase::ALTR);
 			}
 			active_modem->set_freq(brwsViewer->freq(sel));
+			recenter_spectrum_viewer();
 			active_modem->set_sigsearch(SIGSEARCH);
 			if (mainViewer)
 				mainViewer->select(sel);
@@ -236,6 +246,8 @@ static void cb_Squelch(Fl_Slider *, void *)
 {
 	if (active_modem->get_mode() == MODE_RTTY)
 		progStatus.VIEWER_rttysquelch = sldrViewerSquelch->value();
+	else if (active_modem->get_mode() == MODE_CW)
+		progStatus.VIEWER_cwsquelch = sldrViewerSquelch->value();
 	else
 		progStatus.VIEWER_psksquelch = sldrViewerSquelch->value();
 
@@ -349,7 +361,6 @@ void openViewer()
 {
 	if (!dlgViewer) {
 		dlgViewer = createViewer();
-		initViewer();
 	}
 	initViewer();
 	dlgViewer->show();
@@ -358,38 +369,20 @@ void openViewer()
 
 void viewer_paste_freq(int freq)
 {
-//	if (pskviewer) {
-		for (int i = 0; i < progdefaults.VIEWERchannels; i++) {
-			int ftest = active_modem->viewer_get_freq(i);
-			if (ftest == NULLFREQ) continue;
-			if (fabs(ftest - freq) <= 50) {
-				if (progdefaults.VIEWERascend)
-					i = (progdefaults.VIEWERchannels - i);
-				else i++;
-				if (mainViewer)
-					mainViewer->select(i);
-				if (brwsViewer)
-					brwsViewer->select(i);
-				return;
-			}
+	for (int i = 0; i < progdefaults.VIEWERchannels; i++) {
+		int ftest = active_modem->viewer_get_freq(i);
+		if (ftest == NULLFREQ) continue;
+		if (fabs(ftest - freq) <= 50) {
+			if (progdefaults.VIEWERascend)
+				i = (progdefaults.VIEWERchannels - i);
+			else i++;
+			if (mainViewer)
+				mainViewer->select(i);
+			if (brwsViewer)
+				brwsViewer->select(i);
+			return;
 		}
-//	}
-//	if (rttyviewer) {
-//		for (int i = 0; i < progdefaults.VIEWERchannels; i++) {
-//			int ftest = rttyviewer->get_freq(i);
-//			if (ftest == NULLFREQ) continue;
-//			if (fabs(ftest - freq) <= 50) {
-//				if (progdefaults.VIEWERascend)
-//					i = (progdefaults.VIEWERchannels - i);
-//				else i++;
-//				if (mainViewer)
-//					mainViewer->select(i);
-//				if (brwsViewer)
-//					brwsViewer->select(i);
-//				return;
-//			}
-//		}
-//	}
+	}
 }
 
 
