@@ -81,7 +81,7 @@ public:
 	void init();
 	void rx_init();
 	void rx_flush();
-	void tx_init(SoundBase *sc);
+	void tx_init();
 	void restart();
 	int rx_process(const double *buf, int len);
 	int tx_process();
