@@ -938,6 +938,9 @@ void configuration::testCommPorts()
 		select_nanoCW_CommPort->add(gbuf.gl_pathv[j]);
 		select_CW_KEYLINE_CommPort->add(gbuf.gl_pathv[j]);
 
+		select_USN_FSK_port->add(gbuf.gl_pathv[j]);
+		select_Nav_config_port->add(gbuf.gl_pathv[j]);
+
 		select_WK_CommPort->add(gbuf.gl_pathv[j]);
 		select_WKFSK_CommPort->add(gbuf.gl_pathv[j]);
 	}
@@ -973,6 +976,9 @@ void configuration::testCommPorts()
 			select_nanoCW_CommPort->add(ttyname);
 			select_CW_KEYLINE_CommPort->add(ttyname);
 
+			select_USN_FSK_port->add(ttyname);
+			select_Nav_config_port->add(ttyname);
+
 			select_WK_CommPort->add(ttyname);
 			select_WKFSK_CommPort->add(ttyname);
 		}
