@@ -42,6 +42,8 @@
 
 using namespace std;
 
+namespace icons {
+
 #if USE_IMAGE_LABELS
 typedef map<Fl_Multi_Label*, Fl_Image**> imap_t;
 static imap_t* imap = 0;
@@ -76,7 +78,7 @@ const char* make_icon_label(const char* text, const char** pixmap)
 	Fl_Image** images = new Fl_Image*[2];
 	images[0] = new Fl_Pixmap(pixmap ? pixmap : clear_row_icon);
 	images[1] = 0; // we create this on demand
-	// set_icon_label_ will set mlabel->labela later
+				   // set_icon_label_ will set mlabel->labela later
 	mlabel->typea = _FL_IMAGE_LABEL;
 
 	if (!text)
@@ -255,3 +257,5 @@ void set_message_icon(const char** pixmap)
 	msg->box(FL_NO_BOX);
 	msg->image(msg_icon = new Fl_Pixmap(pixmap));
 }
+
+} // icons
