@@ -1446,20 +1446,18 @@ private:
 			if (m_average_early_signal > m_average_late_signal) {
 				// move prompt to where early is
 				slope = m_next_early_event - m_next_prompt_event;
+				slope = fmod(slope - m_bit_sample_count, m_bit_sample_count);
 				m_average_late_signal = m_average_prompt_signal;
 				m_average_prompt_signal = m_average_early_signal;
 			} else {
 				// move prompt to where late is
 				slope = m_next_late_event - m_next_prompt_event;
+				slope = fmod(slope + m_bit_sample_count, m_bit_sample_count);
 				m_average_early_signal = m_average_prompt_signal;
 				m_average_prompt_signal = m_average_late_signal;
 			}
-		} else if (m_average_prompt_signal > m_average_late_signal &&
-			 m_average_prompt_signal > m_average_late_signal)
-			// Limit the adjustment, to ride out noise
-			slope /= 128;
-		else
-			slope /= 32;
+		} else
+			slope /= 64;
 
 		if (slope) {
 			m_next_early_event += slope;
